@@ -99,6 +99,7 @@ fn rem_euclid_2(x: f64) -> f64 {
 macro_rules! impl_log {
     ($(#[$meta:meta])* $f:ident, $f_impl:ident, $f_rd:ident, $f_ru:ident) => {
         $(#[$meta])*
+        #[must_use]
         pub fn $f(self) -> Self {
             self.$f_impl().0
         }
@@ -129,6 +130,7 @@ macro_rules! impl_log {
 macro_rules! impl_mono_inc {
     ($(#[$meta:meta])* $f:ident, $f_rd:ident, $f_ru:ident) => {
         $(#[$meta])*
+        #[must_use]
         pub fn $f(self) -> Self {
             if self.is_empty() {
                 return self;
@@ -142,9 +144,12 @@ macro_rules! impl_mono_inc {
 impl Interval {
     /// Returns the inverse cosine of `self`.
     ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain      | Range      |
     /// | ----------- | ---------- |
     /// | $\[-1, 1\]$ | $\[0, π\]$ |
+    #[must_use]
     pub fn acos(self) -> Self {
         self.acos_impl().0
     }
@@ -168,9 +173,12 @@ impl Interval {
 
     /// Returns the inverse hyperbolic cosine of `self`.
     ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain    | Range     |
     /// | --------- | --------- |
     /// | $\[1, ∞)$ | $\[0, ∞)$ |
+    #[must_use]
     pub fn acosh(self) -> Self {
         self.acosh_impl().0
     }
@@ -194,9 +202,12 @@ impl Interval {
 
     /// Returns the inverse sine of `self`.
     ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain      | Range           |
     /// | ----------- | --------------- |
     /// | $\[-1, 1\]$ | $\[-π/2, π/2\]$ |
+    #[must_use]
     pub fn asin(self) -> Self {
         self.asin_impl().0
     }
@@ -221,6 +232,8 @@ impl Interval {
     impl_mono_inc!(
         /// Returns the inverse hyperbolic sine of `self`.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain | Range |
         /// | ------ | ----- |
         /// | $\R$   | $\R$  |
@@ -231,6 +244,8 @@ impl Interval {
     impl_mono_inc!(
         /// Returns the inverse tangent of `self`.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain | Range         |
         /// | ------ | ------------- |
         /// | $\R$   | $(-π/2, π/2)$ |
@@ -242,9 +257,12 @@ impl Interval {
     /// Returns the angle of the point $(\rhs, \self)$ measured counterclockwise from the positive
     /// $x$-axis in the Euclidean plane.
     ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain                | Range      |
     /// | --------------------- | ---------- |
     /// | $\R^2 ∖ \set{(0, 0)}$ | $(-π, π\]$ |
+    #[must_use]
     pub fn atan2(self, rhs: Self) -> Self {
         self.atan2_impl(rhs).0
     }
@@ -362,9 +380,12 @@ impl Interval {
 
     /// Returns the inverse hyperbolic tangent of `self`.
     ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain    | Range |
     /// | --------- | ----- |
     /// | $(-1, 1)$ | $\R$  |
+    #[must_use]
     pub fn atanh(self) -> Self {
         self.atanh_impl().0
     }
@@ -394,9 +415,12 @@ impl Interval {
 
     /// Returns the cosine of `self`.
     ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain | Range       |
     /// | ------ | ----------- |
     /// | $\R$   | $\[-1, 1\]$ |
+    #[must_use]
     pub fn cos(self) -> Self {
         if self.is_empty() {
             return self;
@@ -440,9 +464,12 @@ impl Interval {
 
     /// Returns the hyperbolic cosine of `self`.
     ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain | Range     |
     /// | ------ | --------- |
     /// | $\R$   | $\[1, ∞)$ |
+    #[must_use]
     pub fn cosh(self) -> Self {
         if self.is_empty() {
             return self;
@@ -462,6 +489,8 @@ impl Interval {
     impl_mono_inc!(
         /// Returns `self` raised to the power of $\e$.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain | Range    |
         /// | ------ | -------- |
         /// | $\R$   | $(0, ∞)$ |
@@ -472,6 +501,8 @@ impl Interval {
     impl_mono_inc!(
         /// Returns `self` raised to the power of 10.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain | Range    |
         /// | ------ | -------- |
         /// | $\R$   | $(0, ∞)$ |
@@ -482,6 +513,8 @@ impl Interval {
     impl_mono_inc!(
         /// Returns `self` raised to the power of 2.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain | Range    |
         /// | ------ | -------- |
         /// | $\R$   | $(0, ∞)$ |
@@ -493,6 +526,8 @@ impl Interval {
     impl_log!(
         /// Returns the natural logarithm of `self`.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain   | Range |
         /// | -------- | ----- |
         /// | $(0, ∞)$ | $\R$  |
@@ -504,6 +539,8 @@ impl Interval {
     impl_log!(
         /// Returns the base-10 logarithm of `self`.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain   | Range |
         /// | -------- | ----- |
         /// | $(0, ∞)$ | $\R$  |
@@ -515,6 +552,8 @@ impl Interval {
     impl_log!(
         /// Returns the base-2 logarithm of `self`.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain   | Range |
         /// | -------- | ----- |
         /// | $(0, ∞)$ | $\R$  |
@@ -526,9 +565,21 @@ impl Interval {
 
     /// Returns `self` raised to the power of `rhs`.
     ///
+    /// The point function is defined as follows:
+    ///
+    /// $$
+    /// x^y = \begin{cases}
+    ///   0           & \for x = 0 ∧ y > 0, \\\\
+    ///   e^{y \ln x} & \for x > 0.
+    ///  \end{cases}
+    /// $$
+    ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain                              | Range     |
     /// | ----------------------------------- | --------- |
     /// | $((0, ∞) × \R) ∪ (\set 0 × (0, ∞))$ | $\[0, ∞)$ |
+    #[must_use]
     pub fn pow(self, rhs: Self) -> Self {
         self.pow_impl(rhs).0
     }
@@ -600,7 +651,17 @@ impl Interval {
 
     /// Returns `self` raised to the power of `rhs`.
     ///
-    /// For a fixed $n ∈ \Z$, the domain and the range of the point function $\operatorname{pown}(x, n)$ are:
+    /// The point functions are indexed by $n$, and are defined as follows:
+    ///
+    /// $$
+    /// x^n = \begin{cases}
+    ///   \overbrace{x × ⋯ × x}^{n \text{ copies}} & \for n > 0, \\\\
+    ///   1          & \for n = 0, \\\\
+    ///   1 / x^{-n} & \for n < 0.
+    ///  \end{cases}
+    /// $$
+    ///
+    /// The domains and the ranges of the point functions are:
     ///
     /// |                | Domain        | Range         |
     /// | -------------- | ------------- | ------------- |
@@ -609,11 +670,12 @@ impl Interval {
     /// | $n = 0$        | $\R$          | $\set 1$      |
     /// | $n < 0$, odd   | $\R ∖ \set 0$ | $\R ∖ \set 0$ |
     /// | $n < 0$, even  | $\R ∖ \set 0$ | $(0, ∞)$      |
-    pub fn pown(self, rhs: i32) -> Self {
-        self.pown_impl(rhs).0
+    #[must_use]
+    pub fn powi(self, rhs: i32) -> Self {
+        self.powi_impl(rhs).0
     }
 
-    fn pown_impl(self, rhs: i32) -> (Self, Decoration) {
+    fn powi_impl(self, rhs: i32) -> (Self, Decoration) {
         if self.is_empty() {
             return (self, Decoration::Trv);
         }
@@ -670,9 +732,12 @@ impl Interval {
 
     /// Returns the sine of `self`.
     ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain | Range       |
     /// | ------ | ----------- |
     /// | $\R$   | $\[-1, 1\]$ |
+    #[must_use]
     pub fn sin(self) -> Self {
         if self.is_empty() {
             return self;
@@ -706,6 +771,8 @@ impl Interval {
     impl_mono_inc!(
         /// Returns the hyperbolic sine of `self`.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain | Range |
         /// | ------ | ----- |
         /// | $\R$   | $\R$  |
@@ -716,9 +783,12 @@ impl Interval {
 
     /// Returns the tangent of `self`.
     ///
+    /// The domain and the range of the point function are:
+    ///
     /// | Domain                            | Range |
     /// | --------------------------------- | ----- |
     /// | $\R ∖ \set{(n + 1/2) π ∣ n ∈ \Z}$ | $\R$  |
+    #[must_use]
     pub fn tan(self) -> Self {
         self.tan_impl().0
     }
@@ -749,6 +819,8 @@ impl Interval {
     impl_mono_inc!(
         /// Returns the hyperbolic tangent of `self`.
         ///
+        /// The domain and the range of the point function are:
+        ///
         /// | Domain | Range     |
         /// | ------ | --------- |
         /// | $\R$   | $(-1, 1)$ |
@@ -763,6 +835,7 @@ macro_rules! impl_dec {
         #[doc = concat!("The decorated version of [`Interval::", stringify!($f), "`].")]
         ///
         /// A NaI is returned if `self` is NaI.
+        #[must_use]
         pub fn $f(self) -> Self {
             Self::set_dec(self.x.$f(), self.d)
         }
@@ -772,6 +845,7 @@ macro_rules! impl_dec {
         #[doc = concat!("The decorated version of [`Interval::", stringify!($f), "`].")]
         ///
         /// A NaI is returned if `self` is NaI.
+        #[must_use]
         pub fn $f(self) -> Self {
             let (y, d) = self.x.$f_impl();
             Self::set_dec(y, self.d.min(d))
@@ -784,6 +858,7 @@ macro_rules! impl_dec2 {
         #[doc = concat!("The decorated version of [`Interval::", stringify!($f), "`].")]
         ///
         /// A NaI is returned if `self` or `rhs` is NaI.
+        #[must_use]
         pub fn $f(self, rhs: Self) -> Self {
             let (z, d) = self.x.$f_impl(rhs.x);
             Self::set_dec(z, self.d.min(rhs.d.min(d)))
@@ -809,11 +884,12 @@ impl DecInterval {
     impl_dec!(log2, log2_impl);
     impl_dec2!(pow, pow_impl);
 
-    /// The decorated version of [`Interval::pown`].
+    /// The decorated version of [`Interval::powi`].
     ///
     /// A NaI is returned if `self` is NaI.
-    pub fn pown(self, rhs: i32) -> Self {
-        let (y, d) = self.x.pown_impl(rhs);
+    #[must_use]
+    pub fn powi(self, rhs: i32) -> Self {
+        let (y, d) = self.x.powi_impl(rhs);
         Self::set_dec(y, self.d.min(d))
     }
 
@@ -849,7 +925,7 @@ mod tests {
         assert!(DI::NAI.log2().is_nai());
         assert!(DI::NAI.pow(DI::EMPTY).is_nai());
         assert!(DI::EMPTY.pow(DI::NAI).is_nai());
-        assert!(DI::NAI.pown(1).is_nai());
+        assert!(DI::NAI.powi(1).is_nai());
         assert!(DI::NAI.sin().is_nai());
         assert!(DI::NAI.sinh().is_nai());
         assert!(DI::NAI.tan().is_nai());
