@@ -21,7 +21,6 @@
  *
  */
 //Language imports
-#![rustfmt::skip]
 
 //Test library imports
 
@@ -36,7 +35,10 @@ fn minimal_nums_to_interval_test() {
     assert_eq2!(n2i(-1.0, 1.0), n2i(-1.0, 1.0));
     assert_eq2!(n2i(f64::NEG_INFINITY, 1.0), n2i(f64::NEG_INFINITY, 1.0));
     assert_eq2!(n2i(-1.0, f64::INFINITY), n2i(-1.0, f64::INFINITY));
-    assert_eq2!(n2i(f64::NEG_INFINITY, f64::INFINITY), n2i(f64::NEG_INFINITY, f64::INFINITY));
+    assert_eq2!(
+        n2i(f64::NEG_INFINITY, f64::INFINITY),
+        n2i(f64::NEG_INFINITY, f64::INFINITY)
+    );
     assert_eq2!(n2i(f64::NAN, f64::NAN), I::EMPTY);
     assert_eq2!(n2i(1.0, -1.0), I::EMPTY);
     assert_eq2!(n2i(f64::NEG_INFINITY, f64::NEG_INFINITY), I::EMPTY);
@@ -46,9 +48,18 @@ fn minimal_nums_to_interval_test() {
 #[test]
 fn minimal_nums_to_decorated_interval_test() {
     assert_eq2!(n2di(-1.0, 1.0), nd2di(-1.0, 1.0, D::Com));
-    assert_eq2!(n2di(f64::NEG_INFINITY, 1.0), nd2di(f64::NEG_INFINITY, 1.0, D::Dac));
-    assert_eq2!(n2di(-1.0, f64::INFINITY), nd2di(-1.0, f64::INFINITY, D::Dac));
-    assert_eq2!(n2di(f64::NEG_INFINITY, f64::INFINITY), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
+    assert_eq2!(
+        n2di(f64::NEG_INFINITY, 1.0),
+        nd2di(f64::NEG_INFINITY, 1.0, D::Dac)
+    );
+    assert_eq2!(
+        n2di(-1.0, f64::INFINITY),
+        nd2di(-1.0, f64::INFINITY, D::Dac)
+    );
+    assert_eq2!(
+        n2di(f64::NEG_INFINITY, f64::INFINITY),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac)
+    );
     assert_eq2!(n2di(f64::NAN, f64::NAN), DI::NAI);
     assert_eq2!(n2di(1.0, -1.0), DI::NAI);
     assert_eq2!(n2di(f64::NEG_INFINITY, f64::NEG_INFINITY), DI::NAI);
@@ -67,7 +78,10 @@ fn minimal_text_to_interval_test() {
     assert_eq2!(t2i("[ entire  ]"), n2i(f64::NEG_INFINITY, f64::INFINITY));
     assert_eq2!(t2i("[ ENTIRE ]_dac"), I::EMPTY);
     assert_eq2!(t2i("[ ENTIRE ]"), n2i(f64::NEG_INFINITY, f64::INFINITY));
-    assert_eq2!(t2i("[ -inf , INF  ]"), n2i(f64::NEG_INFINITY, f64::INFINITY));
+    assert_eq2!(
+        t2i("[ -inf , INF  ]"),
+        n2i(f64::NEG_INFINITY, f64::INFINITY)
+    );
     assert_eq2!(t2i("[ -inf, INF ]_def"), I::EMPTY);
     assert_eq2!(t2i("[-1.0,1.0]"), n2i(-1.0, 1.0));
     assert_eq2!(t2i("[  -1.0  ,  1.0  ]"), n2i(-1.0, 1.0));
@@ -77,7 +91,10 @@ fn minimal_text_to_interval_test() {
     assert_eq2!(t2i("[-1.0, +infinity]"), n2i(-1.0, f64::INFINITY));
     assert_eq2!(t2i("[-Inf, 1.000 ]"), n2i(f64::NEG_INFINITY, 1.0));
     assert_eq2!(t2i("[-Infinity, 1.000 ]"), n2i(f64::NEG_INFINITY, 1.0));
-    assert_eq2!(t2i("[1.0E+400 ]"), n2i(1.7976931348623157e+308, f64::INFINITY));
+    assert_eq2!(
+        t2i("[1.0E+400 ]"),
+        n2i(1.7976931348623157e+308, f64::INFINITY)
+    );
     assert_eq2!(t2i("[ -4/2, 10/5 ]"), n2i(-2.0, 2.0));
     assert_eq2!(t2i("[ -1/10, 1/10 ]"), n2i(-0.1, 0.1));
     assert_eq2!(t2i("0.0?"), n2i(-0.05, 0.05));
@@ -98,7 +115,10 @@ fn minimal_text_to_interval_test() {
     assert_eq2!(t2i("2.5??"), n2i(f64::NEG_INFINITY, f64::INFINITY));
     assert_eq2!(t2i("2.5??u"), n2i(2.5, f64::INFINITY));
     assert_eq2!(t2i("2.5??d"), n2i(f64::NEG_INFINITY, 2.5));
-    assert_eq2!(t2i("2.500?5e+27"), n2i(2.4949999999999995e+27, 2.5050000000000003e+27));
+    assert_eq2!(
+        t2i("2.500?5e+27"),
+        n2i(2.4949999999999995e+27, 2.5050000000000003e+27)
+    );
     assert_eq2!(t2i("2.500?5ue4"), n2i(25000.0, 25050.0));
     assert_eq2!(t2i("2.500?5de-5"), n2i(2.495e-05, 2.5e-05));
     assert_eq2!(t2i("10?3"), n2i(7.0, 13.0));
@@ -128,7 +148,10 @@ fn minimal_text_to_interval_test() {
     assert_eq2!(t2i("0.0??u_ill"), I::EMPTY);
     assert_eq2!(t2i("0.0??d_com"), I::EMPTY);
     assert_eq2!(t2i("[1.0000000000000002,1.0000000000000001]"), I::EMPTY);
-    assert_eq2!(t2i("[10000000000000001/10000000000000000,10000000000000002/10000000000000001]"), I::EMPTY);
+    assert_eq2!(
+        t2i("[10000000000000001/10000000000000000,10000000000000002/10000000000000001]"),
+        I::EMPTY
+    );
     assert_eq2!(t2i("[0x1.00000000000002p0,0x1.00000000000001p0]"), I::EMPTY);
 }
 
@@ -140,48 +163,93 @@ fn minimal_text_to_decorated_interval_test() {
     assert_eq2!(t2di("[  ]"), DI::EMPTY);
     assert_eq2!(t2di("[  ]_trv"), DI::EMPTY);
     assert_eq2!(t2di("[,]"), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
-    assert_eq2!(t2di("[,]_trv"), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Trv));
-    assert_eq2!(t2di("[ entire  ]"), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
-    assert_eq2!(t2di("[ ENTIRE ]_dac"), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
-    assert_eq2!(t2di("[ -inf , INF  ]"), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
-    assert_eq2!(t2di("[ -inf, INF ]_def"), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Def));
+    assert_eq2!(
+        t2di("[,]_trv"),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Trv)
+    );
+    assert_eq2!(
+        t2di("[ entire  ]"),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac)
+    );
+    assert_eq2!(
+        t2di("[ ENTIRE ]_dac"),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac)
+    );
+    assert_eq2!(
+        t2di("[ -inf , INF  ]"),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac)
+    );
+    assert_eq2!(
+        t2di("[ -inf, INF ]_def"),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Def)
+    );
     assert_eq2!(t2di("[-1.0,1.0]"), nd2di(-1.0, 1.0, D::Com));
     assert_eq2!(t2di("[  -1.0  ,  1.0  ]_com"), nd2di(-1.0, 1.0, D::Com));
     assert_eq2!(t2di("[  -1.0  , 1.0]_trv"), nd2di(-1.0, 1.0, D::Trv));
     assert_eq2!(t2di("[-1,]"), nd2di(-1.0, f64::INFINITY, D::Dac));
     assert_eq2!(t2di("[-1.0, +inf]_def"), nd2di(-1.0, f64::INFINITY, D::Def));
-    assert_eq2!(t2di("[-1.0, +infinity]_def"), nd2di(-1.0, f64::INFINITY, D::Def));
-    assert_eq2!(t2di("[-Inf, 1.000 ]"), nd2di(f64::NEG_INFINITY, 1.0, D::Dac));
-    assert_eq2!(t2di("[-Infinity, 1.000 ]_trv"), nd2di(f64::NEG_INFINITY, 1.0, D::Trv));
-    assert_eq2!(t2di("[1.0E+400 ]_com"), nd2di(1.7976931348623157e+308, f64::INFINITY, D::Dac));
+    assert_eq2!(
+        t2di("[-1.0, +infinity]_def"),
+        nd2di(-1.0, f64::INFINITY, D::Def)
+    );
+    assert_eq2!(
+        t2di("[-Inf, 1.000 ]"),
+        nd2di(f64::NEG_INFINITY, 1.0, D::Dac)
+    );
+    assert_eq2!(
+        t2di("[-Infinity, 1.000 ]_trv"),
+        nd2di(f64::NEG_INFINITY, 1.0, D::Trv)
+    );
+    assert_eq2!(
+        t2di("[1.0E+400 ]_com"),
+        nd2di(1.7976931348623157e+308, f64::INFINITY, D::Dac)
+    );
     assert_eq2!(t2di("[ -4/2, 10/5 ]_com"), nd2di(-2.0, 2.0, D::Com));
     assert_eq2!(t2di("[ -1/10, 1/10 ]_com"), nd2di(-0.1, 0.1, D::Com));
     assert_eq2!(t2di("0.0?"), nd2di(-0.05, 0.05, D::Com));
     assert_eq2!(t2di("0.0?u_trv"), nd2di(0.0, 0.05, D::Trv));
     assert_eq2!(t2di("0.0?d_dac"), nd2di(-0.05, 0.0, D::Dac));
-    assert_eq2!(t2di("2.5?"), nd2di(2.4499999999999997, 2.5500000000000003, D::Com));
+    assert_eq2!(
+        t2di("2.5?"),
+        nd2di(2.4499999999999997, 2.5500000000000003, D::Com)
+    );
     assert_eq2!(t2di("2.5?u"), nd2di(2.5, 2.5500000000000003, D::Com));
     assert_eq2!(t2di("2.5?d_trv"), nd2di(2.4499999999999997, 2.5, D::Trv));
     assert_eq2!(t2di("0.000?5"), nd2di(-0.005, 0.005, D::Com));
     assert_eq2!(t2di("0.000?5u_def"), nd2di(0.0, 0.005, D::Def));
     assert_eq2!(t2di("0.000?5d"), nd2di(-0.005, 0.0, D::Com));
-    assert_eq2!(t2di("2.500?5"), nd2di(2.4949999999999997, 2.5050000000000003, D::Com));
+    assert_eq2!(
+        t2di("2.500?5"),
+        nd2di(2.4949999999999997, 2.5050000000000003, D::Com)
+    );
     assert_eq2!(t2di("2.500?5u"), nd2di(2.5, 2.5050000000000003, D::Com));
     assert_eq2!(t2di("2.500?5d"), nd2di(2.4949999999999997, 2.5, D::Com));
-    assert_eq2!(t2di("0.0??_dac"), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
+    assert_eq2!(
+        t2di("0.0??_dac"),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac)
+    );
     assert_eq2!(t2di("0.0??u_trv"), nd2di(0.0, f64::INFINITY, D::Trv));
     assert_eq2!(t2di("0.0??d"), nd2di(f64::NEG_INFINITY, 0.0, D::Dac));
-    assert_eq2!(t2di("2.5??"), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
+    assert_eq2!(
+        t2di("2.5??"),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac)
+    );
     assert_eq2!(t2di("2.5??u_def"), nd2di(2.5, f64::INFINITY, D::Def));
     assert_eq2!(t2di("2.5??d_dac"), nd2di(f64::NEG_INFINITY, 2.5, D::Dac));
-    assert_eq2!(t2di("2.500?5e+27"), nd2di(2.4949999999999995e+27, 2.5050000000000003e+27, D::Com));
+    assert_eq2!(
+        t2di("2.500?5e+27"),
+        nd2di(2.4949999999999995e+27, 2.5050000000000003e+27, D::Com)
+    );
     assert_eq2!(t2di("2.500?5ue4_def"), nd2di(25000.0, 25050.0, D::Def));
     assert_eq2!(t2di("2.500?5de-5"), nd2di(2.495e-05, 2.5e-05, D::Com));
     assert_eq2!(t2di("[ Nai  ]"), DI::NAI);
     // 10?18 + 308 zeros + _com
     assert_eq2!(t2di("10?1800000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000_com"), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
     assert_eq2!(t2di("10?3_com"), nd2di(7.0, 13.0, D::Com));
-    assert_eq2!(t2di("10?3e380_com"), nd2di(1.7976931348623157e+308, f64::INFINITY, D::Dac));
+    assert_eq2!(
+        t2di("10?3e380_com"),
+        nd2di(1.7976931348623157e+308, f64::INFINITY, D::Dac)
+    );
     assert_eq2!(t2di("[ Nai  ]_ill"), DI::NAI);
     assert_eq2!(t2di("[ Nai  ]_trv"), DI::NAI);
     assert_eq2!(t2di("[ Empty  ]_ill"), DI::NAI);
@@ -205,66 +273,214 @@ fn minimal_text_to_decorated_interval_test() {
     assert_eq2!(t2di("0.0??_com"), DI::NAI);
     assert_eq2!(t2di("[1.0,2.0"), DI::NAI);
     assert_eq2!(t2di("[1.0000000000000002,1.0000000000000001]"), DI::NAI);
-    assert_eq2!(t2di("[10000000000000001/10000000000000000,10000000000000002/10000000000000001]"), DI::NAI);
+    assert_eq2!(
+        t2di("[10000000000000001/10000000000000000,10000000000000002/10000000000000001]"),
+        DI::NAI
+    );
     assert_eq2!(t2di("[0x1.00000000000002p0,0x1.00000000000001p0]"), DI::NAI);
 }
 
 #[test]
 fn minimal_interval_part_test() {
-    assert_eq2!(nd2di(-25.600000873750652, 0.09999999999999999, D::Trv).interval().unwrap_or(I::EMPTY), n2i(-25.600000873750652, 0.09999999999999999));
-    assert_eq2!(nd2di(-25.60000228881836, 0.09999999999999999, D::Com).interval().unwrap_or(I::EMPTY), n2i(-25.60000228881836, 0.09999999999999999));
-    assert_eq2!(nd2di(-25.600000873750652, 0.10000000149011612, D::Dac).interval().unwrap_or(I::EMPTY), n2i(-25.600000873750652, 0.10000000149011612));
-    assert_eq2!(nd2di(-25.60000228881836, 0.10000000149011612, D::Def).interval().unwrap_or(I::EMPTY), n2i(-25.60000228881836, 0.10000000149011612));
-    assert_eq2!(nd2di(-5e-324, -5e-324, D::Trv).interval().unwrap_or(I::EMPTY), n2i(-5e-324, -5e-324));
-    assert_eq2!(nd2di(-5e-324, 5e-324, D::Trv).interval().unwrap_or(I::EMPTY), n2i(-5e-324, 5e-324));
-    assert_eq2!(nd2di(5e-324, 5e-324, D::Trv).interval().unwrap_or(I::EMPTY), n2i(5e-324, 5e-324));
-    assert_eq2!(nd2di(-1.7976931348623157e+308, -1.7976931348623157e+308, D::Trv).interval().unwrap_or(I::EMPTY), n2i(-1.7976931348623157e+308, -1.7976931348623157e+308));
-    assert_eq2!(nd2di(-1.7976931348623157e+308, 1.7976931348623157e+308, D::Trv).interval().unwrap_or(I::EMPTY), n2i(-1.7976931348623157e+308, 1.7976931348623157e+308));
-    assert_eq2!(nd2di(1.7976931348623157e+308, 1.7976931348623157e+308, D::Trv).interval().unwrap_or(I::EMPTY), n2i(1.7976931348623157e+308, 1.7976931348623157e+308));
-    assert_eq2!(nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Trv).interval().unwrap_or(I::EMPTY), n2i(f64::NEG_INFINITY, f64::INFINITY));
+    assert_eq2!(
+        nd2di(-25.600000873750652, 0.09999999999999999, D::Trv)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(-25.600000873750652, 0.09999999999999999)
+    );
+    assert_eq2!(
+        nd2di(-25.60000228881836, 0.09999999999999999, D::Com)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(-25.60000228881836, 0.09999999999999999)
+    );
+    assert_eq2!(
+        nd2di(-25.600000873750652, 0.10000000149011612, D::Dac)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(-25.600000873750652, 0.10000000149011612)
+    );
+    assert_eq2!(
+        nd2di(-25.60000228881836, 0.10000000149011612, D::Def)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(-25.60000228881836, 0.10000000149011612)
+    );
+    assert_eq2!(
+        nd2di(-5e-324, -5e-324, D::Trv)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(-5e-324, -5e-324)
+    );
+    assert_eq2!(
+        nd2di(-5e-324, 5e-324, D::Trv)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(-5e-324, 5e-324)
+    );
+    assert_eq2!(
+        nd2di(5e-324, 5e-324, D::Trv).interval().unwrap_or(I::EMPTY),
+        n2i(5e-324, 5e-324)
+    );
+    assert_eq2!(
+        nd2di(-1.7976931348623157e+308, -1.7976931348623157e+308, D::Trv)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(-1.7976931348623157e+308, -1.7976931348623157e+308)
+    );
+    assert_eq2!(
+        nd2di(-1.7976931348623157e+308, 1.7976931348623157e+308, D::Trv)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(-1.7976931348623157e+308, 1.7976931348623157e+308)
+    );
+    assert_eq2!(
+        nd2di(1.7976931348623157e+308, 1.7976931348623157e+308, D::Trv)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(1.7976931348623157e+308, 1.7976931348623157e+308)
+    );
+    assert_eq2!(
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Trv)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(f64::NEG_INFINITY, f64::INFINITY)
+    );
     assert_eq2!(DI::EMPTY.interval().unwrap_or(I::EMPTY), I::EMPTY);
-    assert_eq2!(nd2di(-25.60000228881836, 0.09999999999999999, D::Com).interval().unwrap_or(I::EMPTY), n2i(-25.60000228881836, 0.09999999999999999));
+    assert_eq2!(
+        nd2di(-25.60000228881836, 0.09999999999999999, D::Com)
+            .interval()
+            .unwrap_or(I::EMPTY),
+        n2i(-25.60000228881836, 0.09999999999999999)
+    );
     assert_eq2!(DI::NAI.interval().unwrap_or(I::EMPTY), I::EMPTY);
 }
 
 #[test]
 fn minimal_new_dec_test() {
-    assert_eq2!(DI::new(n2i(-25.600000873750652, 0.09999999999999999)), nd2di(-25.600000873750652, 0.09999999999999999, D::Com));
-    assert_eq2!(DI::new(n2i(-25.60000228881836, 0.09999999999999999)), nd2di(-25.60000228881836, 0.09999999999999999, D::Com));
-    assert_eq2!(DI::new(n2i(-25.600000873750652, 0.10000000149011612)), nd2di(-25.600000873750652, 0.10000000149011612, D::Com));
-    assert_eq2!(DI::new(n2i(-25.60000228881836, 0.10000000149011612)), nd2di(-25.60000228881836, 0.10000000149011612, D::Com));
-    assert_eq2!(DI::new(n2i(-5e-324, -5e-324)), nd2di(-5e-324, -5e-324, D::Com));
-    assert_eq2!(DI::new(n2i(-5e-324, 5e-324)), nd2di(-5e-324, 5e-324, D::Com));
+    assert_eq2!(
+        DI::new(n2i(-25.600000873750652, 0.09999999999999999)),
+        nd2di(-25.600000873750652, 0.09999999999999999, D::Com)
+    );
+    assert_eq2!(
+        DI::new(n2i(-25.60000228881836, 0.09999999999999999)),
+        nd2di(-25.60000228881836, 0.09999999999999999, D::Com)
+    );
+    assert_eq2!(
+        DI::new(n2i(-25.600000873750652, 0.10000000149011612)),
+        nd2di(-25.600000873750652, 0.10000000149011612, D::Com)
+    );
+    assert_eq2!(
+        DI::new(n2i(-25.60000228881836, 0.10000000149011612)),
+        nd2di(-25.60000228881836, 0.10000000149011612, D::Com)
+    );
+    assert_eq2!(
+        DI::new(n2i(-5e-324, -5e-324)),
+        nd2di(-5e-324, -5e-324, D::Com)
+    );
+    assert_eq2!(
+        DI::new(n2i(-5e-324, 5e-324)),
+        nd2di(-5e-324, 5e-324, D::Com)
+    );
     assert_eq2!(DI::new(n2i(5e-324, 5e-324)), nd2di(5e-324, 5e-324, D::Com));
-    assert_eq2!(DI::new(n2i(-1.7976931348623157e+308, -1.7976931348623157e+308)), nd2di(-1.7976931348623157e+308, -1.7976931348623157e+308, D::Com));
-    assert_eq2!(DI::new(n2i(-1.7976931348623157e+308, 1.7976931348623157e+308)), nd2di(-1.7976931348623157e+308, 1.7976931348623157e+308, D::Com));
-    assert_eq2!(DI::new(n2i(1.7976931348623157e+308, 1.7976931348623157e+308)), nd2di(1.7976931348623157e+308, 1.7976931348623157e+308, D::Com));
-    assert_eq2!(DI::new(n2i(f64::NEG_INFINITY, f64::INFINITY)), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
+    assert_eq2!(
+        DI::new(n2i(-1.7976931348623157e+308, -1.7976931348623157e+308)),
+        nd2di(-1.7976931348623157e+308, -1.7976931348623157e+308, D::Com)
+    );
+    assert_eq2!(
+        DI::new(n2i(-1.7976931348623157e+308, 1.7976931348623157e+308)),
+        nd2di(-1.7976931348623157e+308, 1.7976931348623157e+308, D::Com)
+    );
+    assert_eq2!(
+        DI::new(n2i(1.7976931348623157e+308, 1.7976931348623157e+308)),
+        nd2di(1.7976931348623157e+308, 1.7976931348623157e+308, D::Com)
+    );
+    assert_eq2!(
+        DI::new(n2i(f64::NEG_INFINITY, f64::INFINITY)),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac)
+    );
     assert_eq2!(DI::new(I::EMPTY), DI::EMPTY);
-    assert_eq2!(DI::new(n2i(-25.60000228881836, 0.09999999999999999)), nd2di(-25.60000228881836, 0.09999999999999999, D::Com));
+    assert_eq2!(
+        DI::new(n2i(-25.60000228881836, 0.09999999999999999)),
+        nd2di(-25.60000228881836, 0.09999999999999999, D::Com)
+    );
 }
 
 #[test]
 fn minimal_set_dec_test() {
-    assert_eq2!(DI::set_dec(n2i(-25.600000873750652, 0.09999999999999999), D::Trv), nd2di(-25.600000873750652, 0.09999999999999999, D::Trv));
-    assert_eq2!(DI::set_dec(n2i(-25.60000228881836, 0.09999999999999999), D::Com), nd2di(-25.60000228881836, 0.09999999999999999, D::Com));
-    assert_eq2!(DI::set_dec(n2i(-25.600000873750652, 0.10000000149011612), D::Dac), nd2di(-25.600000873750652, 0.10000000149011612, D::Dac));
-    assert_eq2!(DI::set_dec(n2i(-25.60000228881836, 0.10000000149011612), D::Def), nd2di(-25.60000228881836, 0.10000000149011612, D::Def));
-    assert_eq2!(DI::set_dec(n2i(-5e-324, -5e-324), D::Trv), nd2di(-5e-324, -5e-324, D::Trv));
-    assert_eq2!(DI::set_dec(n2i(-5e-324, 5e-324), D::Def), nd2di(-5e-324, 5e-324, D::Def));
-    assert_eq2!(DI::set_dec(n2i(5e-324, 5e-324), D::Dac), nd2di(5e-324, 5e-324, D::Dac));
-    assert_eq2!(DI::set_dec(n2i(-1.7976931348623157e+308, -1.7976931348623157e+308), D::Com), nd2di(-1.7976931348623157e+308, -1.7976931348623157e+308, D::Com));
-    assert_eq2!(DI::set_dec(n2i(-1.7976931348623157e+308, 1.7976931348623157e+308), D::Def), nd2di(-1.7976931348623157e+308, 1.7976931348623157e+308, D::Def));
-    assert_eq2!(DI::set_dec(n2i(1.7976931348623157e+308, 1.7976931348623157e+308), D::Trv), nd2di(1.7976931348623157e+308, 1.7976931348623157e+308, D::Trv));
-    assert_eq2!(DI::set_dec(n2i(f64::NEG_INFINITY, f64::INFINITY), D::Dac), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
+    assert_eq2!(
+        DI::set_dec(n2i(-25.600000873750652, 0.09999999999999999), D::Trv),
+        nd2di(-25.600000873750652, 0.09999999999999999, D::Trv)
+    );
+    assert_eq2!(
+        DI::set_dec(n2i(-25.60000228881836, 0.09999999999999999), D::Com),
+        nd2di(-25.60000228881836, 0.09999999999999999, D::Com)
+    );
+    assert_eq2!(
+        DI::set_dec(n2i(-25.600000873750652, 0.10000000149011612), D::Dac),
+        nd2di(-25.600000873750652, 0.10000000149011612, D::Dac)
+    );
+    assert_eq2!(
+        DI::set_dec(n2i(-25.60000228881836, 0.10000000149011612), D::Def),
+        nd2di(-25.60000228881836, 0.10000000149011612, D::Def)
+    );
+    assert_eq2!(
+        DI::set_dec(n2i(-5e-324, -5e-324), D::Trv),
+        nd2di(-5e-324, -5e-324, D::Trv)
+    );
+    assert_eq2!(
+        DI::set_dec(n2i(-5e-324, 5e-324), D::Def),
+        nd2di(-5e-324, 5e-324, D::Def)
+    );
+    assert_eq2!(
+        DI::set_dec(n2i(5e-324, 5e-324), D::Dac),
+        nd2di(5e-324, 5e-324, D::Dac)
+    );
+    assert_eq2!(
+        DI::set_dec(
+            n2i(-1.7976931348623157e+308, -1.7976931348623157e+308),
+            D::Com
+        ),
+        nd2di(-1.7976931348623157e+308, -1.7976931348623157e+308, D::Com)
+    );
+    assert_eq2!(
+        DI::set_dec(
+            n2i(-1.7976931348623157e+308, 1.7976931348623157e+308),
+            D::Def
+        ),
+        nd2di(-1.7976931348623157e+308, 1.7976931348623157e+308, D::Def)
+    );
+    assert_eq2!(
+        DI::set_dec(
+            n2i(1.7976931348623157e+308, 1.7976931348623157e+308),
+            D::Trv
+        ),
+        nd2di(1.7976931348623157e+308, 1.7976931348623157e+308, D::Trv)
+    );
+    assert_eq2!(
+        DI::set_dec(n2i(f64::NEG_INFINITY, f64::INFINITY), D::Dac),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac)
+    );
     assert_eq2!(DI::set_dec(I::EMPTY, D::Trv), DI::EMPTY);
-    assert_eq2!(DI::set_dec(n2i(-25.60000228881836, 0.09999999999999999), D::Com), nd2di(-25.60000228881836, 0.09999999999999999, D::Com));
+    assert_eq2!(
+        DI::set_dec(n2i(-25.60000228881836, 0.09999999999999999), D::Com),
+        nd2di(-25.60000228881836, 0.09999999999999999, D::Com)
+    );
     assert_eq2!(DI::set_dec(I::EMPTY, D::Def), DI::EMPTY);
     assert_eq2!(DI::set_dec(I::EMPTY, D::Dac), DI::EMPTY);
     assert_eq2!(DI::set_dec(I::EMPTY, D::Com), DI::EMPTY);
-    assert_eq2!(DI::set_dec(n2i(1.0, f64::INFINITY), D::Com), nd2di(1.0, f64::INFINITY, D::Dac));
-    assert_eq2!(DI::set_dec(n2i(f64::NEG_INFINITY, 3.0), D::Com), nd2di(f64::NEG_INFINITY, 3.0, D::Dac));
-    assert_eq2!(DI::set_dec(n2i(f64::NEG_INFINITY, f64::INFINITY), D::Com), nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac));
+    assert_eq2!(
+        DI::set_dec(n2i(1.0, f64::INFINITY), D::Com),
+        nd2di(1.0, f64::INFINITY, D::Dac)
+    );
+    assert_eq2!(
+        DI::set_dec(n2i(f64::NEG_INFINITY, 3.0), D::Com),
+        nd2di(f64::NEG_INFINITY, 3.0, D::Dac)
+    );
+    assert_eq2!(
+        DI::set_dec(n2i(f64::NEG_INFINITY, f64::INFINITY), D::Com),
+        nd2di(f64::NEG_INFINITY, f64::INFINITY, D::Dac)
+    );
     assert_eq2!(DI::set_dec(I::EMPTY, D::Ill), DI::NAI);
     assert_eq2!(DI::set_dec(n2i(f64::NEG_INFINITY, 3.0), D::Ill), DI::NAI);
     assert_eq2!(DI::set_dec(n2i(-1.0, 3.0), D::Ill), DI::NAI);
